@@ -13,7 +13,8 @@ if platform == 'Rhino':
     # special controls
     # just one!
     st.subheader('Pollination Token for Sync')
-    po_token = special.sync(key='pollination-special-sync')
+    po_token = special.sync(key='pollination-special-sync',
+        delay=5000)
     st.write(po_token)
 
     # common controls
@@ -76,11 +77,30 @@ if platform == 'Rhino':
 
     # text_input = st.text_input(label='Type a', value='a')
     # if text_input == 'a':
-    inputs.send(data={ 
+
+    # prepare legend
+    legend = {
+        'type': 'LegendScreen',
+        'x': '50',
+        'y': '50',
+        'height': '600',
+        'width': '25',
+        'min': 0,
+        'max': 100,
+        'num': 8,
+        'font': 17,
+        'colors': [{'r': '255', 'g': '0', 'b': '0' },
+            {'r': '0', 'g': '255', 'b': '255' }, 
+            {'r': '12', 'g': '123', 'b': '255' }, 
+            {'r': '0', 'g': '255', 'b': '0' }]
+    }
+
+    dynamic_input = { 
         'type': 'Polyline2D',
         'vertices': [[0, 0], [10, 0], [0, length]],
         'color': {'r':255, 'g':0, 'b':0} 
-        },
+        }
+    inputs.send(data=dynamic_input,
         label='GO!',
         defaultChecked=True,
         uniqueId='unique-id-02', 
